==> dominodatalab_data-5.6.0-py3-none-any.whl: feature_store_api_client/models/auth_config_fields.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.field import Field

T = TypeVar("T", bound="AuthConfigFields")


@attr.s(auto_attribs=True)
class AuthConfigFields:
    """ """

    additional_properties: Dict[str, Field] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        auth_config_fields = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = Field.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        auth_config_fields.additional_properties = additional_properties
        return auth_config_fields

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Field:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Field) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> dominodatalab_data-5.11.2-py3-none-any.whl: feature_store_api_client/models/auth_config_fields.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.field import Field


T = TypeVar("T", bound="AuthConfigFields")


@_attrs_define
class AuthConfigFields:
    """ """

    additional_properties: Dict[str, "Field"] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.field import Field

        d = src_dict.copy()
        auth_config_fields = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = Field.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        auth_config_fields.additional_properties = additional_properties
        return auth_config_fields

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "Field":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "Field") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
